@@ -2,9 +2,9 @@
 module.exports = exports = search
 
 var npm = require("./npm.js")
-  , registry = npm.registry
-  , columnify = require('columnify')
+  , columnify = require("columnify")
   , mapToRegistry = require("./utils/map-to-registry.js")
+  , updateIndex = require("./cache/update-index.js")
 
 search.usage = "npm search [some search terms ...]"
 
@@ -58,15 +58,16 @@ function search (args, silent, staleness, cb) {
 }
 
 function getFilteredData (staleness, args, notArgs, cb) {
-  var opts = {
-    timeout : staleness,
-    follow  : true,
-    staleOk : true
-  }
-  mapToRegistry("-/all", npm.config, function (er, uri) {
+  mapToRegistry("-/all", npm.config, function (er, uri, auth) {
     if (er) return cb(er)
 
-    registry.get(uri, opts, function (er, data) {
+    var params = {
+      timeout : staleness,
+      follow  : true,
+      staleOk : true,
+      auth    : auth
+    }
+    updateIndex(uri, params, function (er, data) {
       if (er) return cb(er)
       return cb(null, filter(data, args, notArgs))
     })
@@ -164,7 +165,7 @@ function prettify (data, args) {
       dat.keywords = dat.keywords.split(/[,\s]+/)
     }
     if (Array.isArray(dat.keywords)) {
-      dat.keywords = dat.keywords.join(' ')
+      dat.keywords = dat.keywords.join(" ")
     }
 
     // split author on whitespace or ,
@@ -172,7 +173,7 @@ function prettify (data, args) {
       dat.author = dat.author.split(/[,\s]+/)
     }
     if (Array.isArray(dat.author)) {
-      dat.author = dat.author.join(' ')
+      dat.author = dat.author.join(" ")
     }
     return dat
   })
@@ -194,7 +195,7 @@ function prettify (data, args) {
         include: columns
       , truncate: truncate
       , config: {
-          name: { maxWidth: 40, truncate: false, truncateMarker: '' }
+          name: { maxWidth: 40, truncate: false, truncateMarker: "" }
         , description: { maxWidth: 60 }
         , author: { maxWidth: 20 }
         , date: { maxWidth: 11 }
@@ -260,9 +261,9 @@ function getMaxWidth() {
 
 function trimToMaxWidth(str) {
   var maxWidth = getMaxWidth()
-  return str.split('\n').map(function(line) {
+  return str.split("\n").map(function(line) {
     return line.slice(0, maxWidth)
-  }).join('\n')
+  }).join("\n")
 }
 
 function highlightSearchTerms(str, terms) {
