@@ -1,5 +1,4 @@
 var common = require("../common-tap")
-var fs = require("fs")
 var path = require("path")
 var test = require("tap").test
 var rimraf = require("rimraf")
@@ -9,9 +8,6 @@ var pkg = path.resolve(__dirname, "peer-deps-invalid")
 var cache = path.resolve(pkg, "cache")
 var nodeModules = path.resolve(pkg, "node_modules")
 
-var okFile = fs.readFileSync(path.join(pkg, "file-ok.js"), "utf8")
-var failFile = fs.readFileSync(path.join(pkg, "file-fail.js"), "utf8")
-
 test("installing dependencies that have conflicting peerDependencies", function (t) {
   rimraf.sync(nodeModules)
   rimraf.sync(cache)
@@ -19,11 +15,12 @@ test("installing dependencies that have conflicting peerDependencies", function
 
   var customMocks = {
     "get": {
-      "/ok.js": [200, okFile],
-      "/invalid.js": [200, failFile]
+      "/ok.js": [200, path.join(pkg, "file-ok.js")],
+      "/invalid.js": [200, path.join(pkg, "file-fail.js")]
     }
   }
-  mr({port: common.port, mocks: customMocks}, function (s) { // create mock registry.
+  mr({port: common.port, mocks: customMocks}, function (err, s) { // create mock registry.
+    t.ifError(err, "mock registry started")
     npm.load({
       cache: cache,
       registry: common.registry
